/*
 * This file is part of the OpenKinect Project. http://www.openkinect.org
 *
 * Copyright (c) 2010 individual OpenKinect contributors. See the CONTRIB file
 * for details.
 *
 * This code is licensed to you under the terms of the Apache License, version
 * 2.0, or, at your option, the terms of the GNU General Public License,
 * version 2.0. See the APACHE20 and GPL2 files for the text of the licenses,
 * or the following URLs:
 * http://www.apache.org/licenses/LICENSE-2.0
 * http://www.gnu.org/licenses/gpl-2.0.txt
 *
 * If you redistribute this file in source form, modified or unmodified, you
 * may:
 *   1) Leave this header intact and distribute it under the same terms,
 *      accompanying it with the APACHE20 and GPL20 files, or
 *   2) Delete the Apache 2.0 clause and accompany it with the GPL2 file, or
 *   3) Delete the GPL v2 clause and accompany it with the APACHE20 file
 * In all cases you must keep the copyright notice intact and include a copy
 * of the CONTRIB file.
 *
 * Binary distributions must follow the binary distribution requirements of
 * either License.
 */

import org.openkinect.Context;
import org.openkinect.Device;

import java.awt.Color;
import java.awt.image.BufferedImage;

import java.io.File;
import java.io.IOException;

import java.nio.ShortBuffer;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.imageio.ImageIO;


/**
 * @author Michael Nischt
 */
public class Example {

  /** TODO Field description */
  private Context context;

  /** TODO Field description */
  private DepthImage depthImage;

  /** TODO Field description */
  private Device device;

  /** TODO Field description */
  private BufferedImage video, depth;

  /** TODO Field description */
  private VideoImage videoImage;

  /**
   * TODO Method description
   *
   * @param args
   * @throws IOException
   */
  public static void main(String[] args) throws IOException {
    new Example().run();
  }

  /**
   * TODO Method description
   *
   * @throws IOException
   */
  private void run() throws IOException {
    setup();

    // get the raw data
    ShortBuffer depthData = depthImage.getData();
    int         offset    = 0;
    int         data[][]  = new int[DepthImage.WIDTH][DepthImage.HEIGHT];
    for (int x = 0; x < DepthImage.WIDTH; x++) {
      for (int y = 0; y < DepthImage.HEIGHT; y++) {
        offset     = (y * DepthImage.WIDTH + x);
        data[x][y] = depthData.get(offset);
      }
    }

    for (int x = 0; x < DepthImage.WIDTH; x++) {
      for (int y = 0; y < DepthImage.HEIGHT; y++) {
        if ((data[x][y] > 1500) || (data[x][y] < 1000)) {
          video.setRGB(x, y, Color.PINK.getRGB());
        }
      }
    }

    // DepthImage.HEIGHT
    // DepthImage.WIDTH
    // )
    // ;

    cleanup();
    saveImages();
  } // run

  /**
   * TODO Method description
   *
   */
  private void setup() {

    // create the kinect Image objects
    depthImage = new DepthImage();
    videoImage = new VideoImage();

    // connect to device
    context = Context.getContext();

    if (context.devices() < 1) {
      System.out.println("No Kinect devices found.");
      return;
    }

    device = context.getDevice(0);

    // set up for getting data
    device.depth(depthImage);
    device.color(videoImage);

    // process events from the kinect
    int count = 100;
    for (int i = 0; i < count; i++) {
      context.processEvents();
    } // while

    // get the images
    depth = depthImage.getImage();
    video = videoImage.getImage();
  }

  /**
   * TODO Method description
   *
   */
  private void cleanup() {

    // clean up
    device.depth(null);
    device.color(null);
    device.dispose();
  }

  /**
   * TODO Method description
   *
   */
  private void saveImages() {
    try {
      String home = System.getProperty("user.home");
      ImageIO.write(video, "jpg", new File(home + File.separator + "kinect.video.jpg"));
      ImageIO.write(depth, "jpg", new File(home + File.separator + "kinect.depth.jpg"));
    }
    catch (IOException ex) {
      Logger.getLogger(Example.class.getName()).log(Level.SEVERE, null, ex);
    }

  }
}

